@@ -408,7 +408,8 @@ class LoopRunner(object):
             try:
                 self._loop.add_callback(self._loop.stop)
                 self._loop_thread.join(timeout=timeout)
-                self._loop.close()
+                with ignoring(KeyError):  # IOLoop can be missing
+                    self._loop.close()
             finally:
                 self._loop_thread = None
 
@@ -1372,7 +1373,7 @@ def reset_logger_locks():
 
 
 # Only bother if asyncio has been loaded by Tornado
-if 'asyncio' in sys.modules:
+if 'asyncio' in sys.modules and tornado.version_info[0] >= 5:
 
     jupyter_event_loop_initialized = False
 
